@@ -1,3 +1,4 @@
+# coding=utf-8
 import io
 
 import pkg_resources
@@ -5,13 +6,13 @@ from PIL import Image, ImageDraw, ImageFont, ImageOps
 
 WIDTH = 300
 HEIGHT = 90
-FONT_SIZE = 16
+FONT_SIZE = 10
 FONT = pkg_resources.resource_filename(__name__, 'resources/font.ttf')
 
 
 def draw_date(draw, date):
     font = ImageFont.truetype(FONT, FONT_SIZE)
-    draw.text((10, 30), date.strftime("%d-%m-%Y"), font=font, fill=(0, 0, 0))
+    draw.text((10, 40), "Дата и время: " + date.strftime("%Y-%m-%d %H:%M:%S"), font=font, fill=(0, 0, 0))
 
 
 def draw_longstring(draw, name, position):
@@ -26,13 +27,14 @@ def draw_longstring(draw, name, position):
     draw.text(position, name, font=font, fill=(0, 0, 0))
 
 
-def convert(name, date, a_hash):
+def convert(name, date, a_hash, position):
     img_without_border = Image.new('RGB', (WIDTH, HEIGHT), color=(255, 255, 255))
     img = ImageOps.expand(img_without_border, border=1, fill="black")
 
     d = ImageDraw.Draw(img)
-    draw_date(d, date)
     draw_longstring(d, name, (10, 10))
+    draw_longstring(d, u"Должность: " + position, (10, 25))
+    draw_date(d, date)
     draw_longstring(d, a_hash, (10, 60))
 
     img_bytes = io.BytesIO()
